@@ -8,12 +8,12 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTestWidgetContainer.php 5881 2013-03-30 12:37:14Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getLibPath() .	'/tcpdf/config/lang/jpn.php');
 require_once($gEnvManager->getLibPath() .	'/tcpdf/tcpdf.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
